MCALF
*****

mcalf Package
=============

MCALF: Multi-Component Atmospheric Line Fitting
-----------------------------------------------

MCALF is an open-source Python package for accurately constraining
velocity information from spectral imaging observations using
machine learning techniques.
